# coding: utf-8
from enum import Enum, unique


@unique
class CriteriaOperator(Enum):
    
    CONTAINS = "CONTAINS"
    EQUALS = "EQUALS"
    EQUALS_IGNORE_CASE = "EQUALS_IGNORE_CASE"
    GREATER_THAN = "GREATER_THAN"
    GREATER_THAN_OR_EQUAL = "GREATER_THAN_OR_EQUAL"
    LESS_THAN = "LESS_THAN"
    LESS_THAN_OR_EQUAL = "LESS_THAN_OR_EQUAL"
    NOT_EQUALS = "NOT_EQUALS"
    NOT_EQUALS_IGNORE_CASE = "NOT_EQUALS_IGNORE_CASE"
    NOT_CONTAINS = "NOT_CONTAINS"
    IS_NULL = "IS_NULL"
    IS_NOT_NULL = "IS_NOT_NULL"

